==> tib-0.6.4.tgz: package/lib/tib-selenium3.js <==
'use strict';

require('path');
require('hable');
require('signal-exit');
require('./tib-chunk.js');
require('os');
require('child_process');
require('tree-kill');
require('vue-template-compiler');
require('@babel/core');
require('@babel/parser');
require('./tib-chunk2.js');
require('./tib-chunk3.js');
const index = require('./tib-index.js');
const __chunk_4 = require('./tib-chunk4.js');

class FirefoxSeleniumBrowser extends __chunk_4.SeleniumLogging(index.default) {
  constructor(config) {
    super(config);

    this.setBrowser('firefox');

    this.hook('selenium:build:before', async (builder) => {
      const configArguments = this.config.browserArguments;

      if (!config.xvfb && !configArguments.some(a => a.includes('headless'))) {
        configArguments.push('headless');
      }

      const options = new FirefoxSeleniumBrowser.client.Options();
      options.addArguments(...configArguments);

      if (this.config.browserConfig.window) {
        options.windowSize(this.config.browserConfig.window.width, this.config.browserConfig.window.height);
      }

      await this.callHook('selenium:build:options', options, builder);

      builder.setFirefoxOptions(options);
    });
  }

  async _loadDependencies() {
    super._loadDependencies();

    if (!FirefoxSeleniumBrowser.geckodriver) {
      FirefoxSeleniumBrowser.geckodriver = await this.loadDependency('geckodriver');
    }

    if (!FirefoxSeleniumBrowser.client) {
      FirefoxSeleniumBrowser.client = await this.loadDependency('selenium-webdriver/firefox');
    }
  }
}

exports.default = FirefoxSeleniumBrowser;

==> tib-0.7.0.tgz: package/lib/tib-selenium3.js <==
'use strict';

require('path');
require('hable');
require('signal-exit');
require('os');
require('child_process');
require('tree-kill');
require('./tib-browserstack-local.js');
require('vue-template-compiler');
require('fs');
require('util');
require('events');
require('assert');
require('crypto');
require('webpack');
require('@babel/core');
require('@babel/parser');
require('./tib-browser.js');
require('http');
require('./tib-webpage.js');
const index = require('./tib-index.js');
const logging = require('./tib-logging.js');

class FirefoxSeleniumBrowser extends logging.SeleniumLogging(index.default) {
  constructor(config) {
    super(config);

    this.setBrowser('firefox');

    this.hook('selenium:build:before', async (builder) => {
      const configArguments = this.config.browserArguments;

      if (!config.xvfb && !configArguments.some(a => a.includes('headless'))) {
        configArguments.push('headless');
      }

      const options = new FirefoxSeleniumBrowser.client.Options();
      options.addArguments(...configArguments);

      if (this.config.browserConfig.window) {
        options.windowSize(this.config.browserConfig.window.width, this.config.browserConfig.window.height);
      }

      await this.callHook('selenium:build:options', options, builder);

      builder.setFirefoxOptions(options);
    });
  }

  async _loadDependencies() {
    super._loadDependencies();

    if (!FirefoxSeleniumBrowser.geckodriver) {
      FirefoxSeleniumBrowser.geckodriver = await this.loadDependency('geckodriver');
    }

    if (!FirefoxSeleniumBrowser.client) {
      FirefoxSeleniumBrowser.client = await this.loadDependency('selenium-webdriver/firefox');
    }
  }
}

exports.default = FirefoxSeleniumBrowser;
